@@ -53,6 +53,17 @@ class Translator():
     
     def xdi82IPA(self, text):
         text=text.replace('⇧','')
-        for fro, to in xdi82IPA_dict.items():
-            text=text.replace(fro,to)
-        return text
+        start=0;end=2
+        tmp=''
+        while len(text) > 0:
+            if text[start] in allxdi8zimu:
+                if text[start:end] in xdi82IPA_dict  and not end>len(text):
+                    end+=1
+                    continue
+                tmp+=xdi82IPA_dict[text[start:end-1]]
+                text=text[end-1:]
+                start=0;end=2
+            else:
+                tmp+=text[start]
+                text=text[1:]
+        return tmp
